==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/RangeColumnSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalRangeCategorySeriesDescriptionMetadata } from "./HorizontalRangeCategorySeriesDescriptionMetadata";
import { RangeColumnSeriesDescription } from "./RangeColumnSeriesDescription";
/**
 * @hidden
 */
export let RangeColumnSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class RangeColumnSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (RangeColumnSeriesDescriptionMetadata.a == null) {
                RangeColumnSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RangeColumnSeriesDescriptionMetadata.c(RangeColumnSeriesDescriptionMetadata.a);
            }
            if (a.j(RangeColumnSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(RangeColumnSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalRangeCategorySeriesDescriptionMetadata.c(a);
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
        }
        static d(a) {
            RangeColumnSeriesDescriptionMetadata.b(a);
            a.aa("RangeColumnSeries", () => new RangeColumnSeriesDescription());
            a.z("RangeColumnSeries", RangeColumnSeriesDescriptionMetadata.a);
        }
    }
    RangeColumnSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(RangeColumnSeriesDescriptionMetadata, 'RangeColumnSeriesDescriptionMetadata');
    RangeColumnSeriesDescriptionMetadata.a = null;
    return RangeColumnSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/RangeColumnSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalRangeCategorySeriesDescriptionMetadata } from "./HorizontalRangeCategorySeriesDescriptionMetadata";
import { RangeColumnSeriesDescription } from "./RangeColumnSeriesDescription";
/**
 * @hidden
 */
export let RangeColumnSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class RangeColumnSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (RangeColumnSeriesDescriptionMetadata.a == null) {
                RangeColumnSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RangeColumnSeriesDescriptionMetadata.c(RangeColumnSeriesDescriptionMetadata.a);
            }
            if (a.k(RangeColumnSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(RangeColumnSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalRangeCategorySeriesDescriptionMetadata.c(a);
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
        }
        static d(a) {
            RangeColumnSeriesDescriptionMetadata.b(a);
            a.ac("RangeColumnSeries", () => new RangeColumnSeriesDescription());
            a.ab("RangeColumnSeries", RangeColumnSeriesDescriptionMetadata.a);
        }
    }
    RangeColumnSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(RangeColumnSeriesDescriptionMetadata, 'RangeColumnSeriesDescriptionMetadata');
    RangeColumnSeriesDescriptionMetadata.a = null;
    return RangeColumnSeriesDescriptionMetadata;
})();
